@@ -37,7 +37,6 @@
 #include <QItemDelegate>
 #include <QLineEdit>
 #include <QList>
-#include <QVector>
 #include <QMenu>
 #include <QPair>
 #include <QPushButton>
@@ -64,7 +63,7 @@ static const QColor PlayerColors[MAX_PLAYERS] = {
 class playersListModel : public QAbstractTableModel
 {
     typedef QPair<QColor, QString> PlayerId;
-    QVector<PlayerId> m_availablePlayerId;
+    QList<PlayerId> m_availablePlayerId;
     NewGameDlg *m_newGameDlg;
 
 public:
@@ -393,7 +392,7 @@ NewGameDlg::updateOwnerCB()
 void
 NewGameDlg::init()
 {
-    KConfigGroup config = KSharedConfig::openConfig()->group("Game");
+    KConfigGroup config = KSharedConfig::openConfig()->group(QStringLiteral("Game"));
 
     int nrOfPlayers = config.readEntry("NrOfPlayers",0);
     if (nrOfPlayers < 2)
@@ -557,7 +556,7 @@ NewGameDlg::slotNewProduction(int value)
 void
 NewGameDlg::save()
 {
-    KConfigGroup config = KSharedConfig::openConfig()->group("Game");
+    KConfigGroup config = KSharedConfig::openConfig()->group(QStringLiteral("Game"));
     
     config.writeEntry("NrOfPlanets", m_w->neutralPlanetsSB->value());
     config.writeEntry("SizeWidth", m_w->widthSB->value());
